species.analysis package
========================

Submodules
----------

species.analysis.compare\_spectra module
----------------------------------------

.. automodule:: species.analysis.compare_spectra
   :members:
   :undoc-members:
   :show-inheritance:

species.analysis.emission\_line module
--------------------------------------

.. automodule:: species.analysis.emission_line
   :members:
   :undoc-members:
   :show-inheritance:

species.analysis.fit\_model module
----------------------------------

.. automodule:: species.analysis.fit_model
   :members:
   :undoc-members:
   :show-inheritance:

species.analysis.fit\_spectrum module
-------------------------------------

.. automodule:: species.analysis.fit_spectrum
   :members:
   :undoc-members:
   :show-inheritance:

species.analysis.photometry module
----------------------------------

.. automodule:: species.analysis.photometry
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: species.analysis
   :members:
   :undoc-members:
   :show-inheritance:
